Python bindings for the RDX parser via PyO3.
Exposes parsing, schema validation, transforms, and utility functions to Python. All AST data is returned as native Python dicts and lists.
Python bindings for the RDX parser via PyO3.
Exposes parsing, schema validation, transforms, and utility functions to Python. All AST data is returned as native Python dicts and lists.